extensions [table matrix]

globals [no-change-for end-tick dom-matrix num-patches num-empty-env
         col-thresh num-deaths num-starve num-eat num-born species-id-cumm new-species-prob
         num-deaths-disp num-starve-disp num-eat-disp num-born-disp num-migrate num-migrate-disp num-entity-species-disp
         dom-floor num-extinctions time-per-tick num-die-old num-die-old-disp bit-mutate-prob
         num-ticks-with-non-zero-pop survival-threshold col-incr dom-matrix-list species-col-table-list dv-vals-list
         filename species-col-table species-id-table species-gene-table species-gene-table-list
         dv-vals pi-t pi-d F-st pi-env F-env F-denv l0 l1 l2+ patch-set-list list-patch-chars
         death-threshold num-die-rand num-muts num-muts-display mut-prob-list innovation-prob-list
         s1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12 s13 s14 s15 s16 pi1 pi2 pi3 pi4 pi5 pi6 pi7 pi8 pi9 pi10 pi11 pi12 pi13 pi14 pi15 pi16
         plant-size pred-size-incr prop-neighbours-same species-id-table-list pop-display 
         sample-patch-x sample-patch-y sample-patches sample-patch-entities 
         num-entity-species entity-num-table entity-num-table-list
         ]

breed [entities entity]

turtles-own [gene energy level age species-id num-eaten]

patches-own [chars resource p-species-id sim-around-chars barrier?]

to setup
  clear-all
  resize-world 0 patches-across - 1 0 patches-across - 1
  set-patch-size 428 / patches-across ;; world is 428 in visual size
  set num-patches (max-pxcor + 1) * (max-pycor + 1) ;; total patches in world
  ifelse (strip-spaces title) = "" [set filename "Ecology Model"] [set filename strip-spaces title]  ;; filename for saving/loading world state or matrix 

  ;; internal parameters
  set survival-threshold max list 200 (2 * food-rate / (life-tax * num-patches))  ;; if population exists for more than this time initialising "seeding" period stops
  set death-threshold 0 ;; minimum energy level to survive
  set col-incr 30 ;; how much colour changes with new mutation
  set col-thresh 20 ;; minimum rgb value that is visible
  set plant-size 0.1 ;; how big plant entities are displayed
  set pred-size-incr 0.025 ;; increment in displayed size for each larger trophic level
  set dom-floor 0 ;; the minimum threshold for dominance (either predation or from patch)
  
  ;; working variables
  set num-ticks-with-non-zero-pop 0 ;; counter for number of consequtive ticks with entities
  set species-id-cumm 0  ;;  increments by 1 every actually new geneome so becomes its species label
  set num-entity-species 0  ;; counts how many unique species there are
  set pop-display 0 ;; current count of turtles so it is not continually calculated but only once a tick
  set new-species-prob init-new-species-prob ;; current probability of a new species entrant
    
  ;; calculated parameters
  set num-empty-env gene-size - num-env-chars ;; size of 0 padding for patch characteristics
  set mut-prob-list n-values gene-size [mut-prob ^ (1 + ?) * (1 - mut-prob) ^ (gene-size - ? - 1) * bin-coef gene-size (1 + ?)]
  
  ;; initialise various lookup tables
  set species-col-table table:make ;; from species id to colour to ensure same species is always coloured the same
  set entity-num-table table:make ;; from species id to the number of that kind existing
  set species-id-table table:make ;; from gene to species id
  set species-gene-table table:make ;; from species id to gene
  set dv-vals table:make ;; cache of dominance value calculations, to avoid recalculation and thus speed simluation
  clear-save-lists

  ;; create new random dominance matrix
  set dom-matrix matrix:from-row-list n-values gene-size [n-values gene-size [rand-val]]
  if anti-sym-mat? [set dom-matrix a-sym dom-matrix]
  
  ;; initialise patches with their characteristics
  set list-patch-chars [] ;; a list of all different patch characteristics
  let n 0
  ask patches [
    set resource 0  ;; starts with no energy
    set chars sentence n-values num-env-chars [rand-bin] n-values num-empty-env [0] ;; set patch to have random characteristics within range
    if not member? chars list-patch-chars [set list-patch-chars fput chars list-patch-chars] ;; add to list of patch characteristics if not there
  ]
  ask patches [set sim-around-chars sim-around chars] ;; each patch records how many of the adjacent 4 patches have the same characteristics as self
  ;; setup patch ids with negative numbers
  let p-id -1 * length list-patch-chars ;; starting as negative as necessary given number of kinds of patches
  ;; for all patches with same characteristics set their patch id and add these to tables
  foreach list-patch-chars [
    ask patches with [chars = ?] [
      set p-species-id p-id
    ]
    table:put species-id-table ? p-id
    table:put species-gene-table p-id ?
    set p-id p-id + 1
  ]
  
  ;; sorting patches and adding barriers
  swap ;; swaps patches until given proportion of patches have same number of similar adjeacent to themselves
  ask patches [
    ifelse prob prop-barriers ;; with this probability change patches to barrier patches
      [set barrier? true set pcolor white]
      [set barrier? false]
  ]

  ;; make list of lists of the same kind of patches to speed some calculations
  set patch-set-list map [patches with [chars = ?]] list-patch-chars
  ;; reset ticks ready for simulation
  reset-ticks
end

;; colours patches
to col-patches
  ask patches [set pcolor (list (col-thresh * (1 + first chars)) (col-thresh * (1 + second chars)) (col-thresh * (1 + third chars)))]
end

;; swaps patches until given proportion of patches have same number of similar adjeacent to themselves
to swap 
  reset-timer
  while [prop-neighbours-same < target-prop-n and timer < max-secs] [ ;; timer added in case its impossible or takes forever
    swap-if-more-similar  ;; only swap if increases similarity
    set prop-neighbours-same mean [sim-around-chars] of patches  ;; calc average similarity level
  ]
  col-patches  ;; recolour them
end

;; takes a random pair of patches then swaps them to increase similarity level (if possible)
to swap-if-more-similar
  let samp 10
  let p1 no-patches let ch1 [] let nsim1 0 let osim1 0
  let p2 no-patches let ch2 [] let nsim2 0 let osim2 0
  set p1 min-one-of (n-of samp patches) [sim-around-chars]
  set ch1 [chars] of p1
  ask p1 [set p2 min-one-of ((n-of samp other patches) with [chars != ch1]) [sim-around-chars]]
  set ch2 [chars] of p2
  ask p1 [set nsim1 sim-around ch1 set osim1 sim-around ch2]
  ask p2 [set nsim2 sim-around ch2 set osim2 sim-around ch1]
  if osim1 + osim2 > nsim1 + nsim2 [
    ask p1 [set chars ch2]
    ask p2 [set chars ch1]
    ask p1 [
      set sim-around-chars sim-around chars
      ask neighbors4 [set sim-around-chars sim-around chars]
    ]
    ask p2 [
      set sim-around-chars sim-around chars
      ask neighbors4 [set sim-around-chars sim-around chars]
    ]
  ]
end

;; calculates proportion of adjacent patches with same characteristics
to-report sim-around [ch]
  report (count neighbors4 with [chars = ch]) / 4
end

;; randomly shifts entities from centre of patch so they can all be seen
to shift
  set xcor [pxcor] of patch-here + random-float 0.9 - 0.45
  set ycor [pycor] of patch-here + random-float 0.9 - 0.45
end

;; adds a matrix to its transpose to make it symettric
to-report a-sym [mat]
  let m2 matrix:plus mat matrix:transpose mat
  report m2
end

;; gives a suitable random entry for the dominance matrix
to-report rand-val
;;  report (random-float 2) - 1
  report random-normal 0 0.3333
end

;; random binary for making/mutating genes/characteristics
to-report rand-bin
  report random 2
end

;; calculates number of entries in two genes/characteristics that are different
to-report hamming-dist [vec1 vec2]
  report sum (map [ifelse-value (?1 = ?2) [0] [1]] vec1 vec2)
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  reset-timer
  ;; if time is done stop simulation
  
  set end-tick ticks ;; so last tick done can be output
  ;; if in initial "seeding" period count time with viable pop
  if new-species-prob > 0 [
    if count entities > 0 
      [set num-ticks-with-non-zero-pop num-ticks-with-non-zero-pop + 1]
    if stop-new-when-est? and num-ticks-with-non-zero-pop > survival-threshold [set new-species-prob 0]
  ]
  
  ;; distribute resources *evenbly* to all patches - resource does not accumulate if unused
  ask patches [set resource food-rate / num-patches]
  
  ;; counts for events set to zero
  set num-starve 0
  set num-die-old 0
  set num-die-rand 0
  set num-muts 0
  
  ;; life tax, aging and death
  ask turtles [
    set energy energy - life-tax
    set age age + 1
    if energy < death-threshold [set num-starve num-starve + 1 death]
    if max-age > 0 and age > max-age [set num-die-old num-die-old + 1 death]
    if prob rand-death-prob [set num-die-rand num-die-rand + 1 death]
  ]
  set num-die-old-disp num-die-old
  set num-starve-disp num-starve
  
  ;; new entities from outside
  if (prob new-species-prob and count turtles = 0) [
    create-new-entity
  ]
  
  ;; extracting energy from the patch
  ;; at the moment the energy is shared by any > dom-floor proportionately
  ask patches [
    if not any? turtles-here [stop]
    let tl sort turtles-here
    if not allow-plant-predators?
      [set tl filter [[level] of ? = 0] tl]  ;; if this parameter not set then only trophic level 0 can extract energy

    let nt (length tl) - 1
    let rl []
    let lf 0
    ifelse neutral-env? ;; if neutral-env? parameter set all get energy equally
      [set rl map [1] tl]
      [set rl map [? - dom-floor] map [max list dom-floor dv p-species-id ([species-id] of ?) ] tl] ;; only those above dom-floor get energy in proportion to domination over patch
    let sumrl sum rl
    ifelse sumrl = 0 
      [set lf 0]
      [set lf resource / sumrl]  ;; calc amount of each share of available energy
    set rl map [ ? * lf] rl
    let i 0
    foreach seq1 0 nt [
      set i item ? rl
      if i > 0 [
        ask item ? tl [set energy energy + efficiency * lf * i]
        set resource resource - lf * i
      ]
    ]
  ]
  
  ;; predation
  set num-eat 0
  let oth-ent nobody
    ask turtles [
      repeat eating-tries [  ;; try eating others this many times
        if any? other turtles-here [
          set oth-ent one-of other turtles-here  ;; randomly choose one other here
          if dom? species-id [species-id] of oth-ent [  ;; only if you dominate them you predate
            set level 1 + [level] of oth-ent
            set energy energy + efficiency * [energy] of oth-ent  ;; amount received depends on efficiency parameter
            ask oth-ent [death]
            set num-eat num-eat + 1
            adjust-display
          ]
        ]
      ]
    ]
    
  set num-eat-disp num-eat ;; update monitor for number eaten
  
  ;; reduce all stores to max-store if this is > 0.  This prevents entities building up HUGE stores of energy
  if max-store > 0 [ ;; if max-store = 0 there is no limit to stores of energy
    ask turtles [
      set energy min list energy max-store
    ]
  ]
  
  ;; entity births
  set num-born 0
  ask entities [
    if energy >= reproduce-level [  ;; only reproduce (once) if energy is above required level
      hatch-1-entity
      set num-born num-born + 1 ;; count of how many children entities it has had
      set energy energy - init-energy ;; the initial energy a child has is subtracted from parent
    ]
  ]
  set num-born-disp num-born ;; update monitor for number born
  set num-muts-display num-muts ;; update monitor for number mutated during birth
  
  ;; entity migration
  set num-migrate 0
  let xm random (max-pxcor + 1)
  let ym random (max-pycor + 1)
  ifelse migrate-near? [   ;; if migrate near switch is set with a probability migrate to an adjacent patch, keep count of these
    ask entities [if prob migration-prob [move-near set num-migrate num-migrate + 1]]
  ] [
    ask entities [    ;; otherwise move to a random patch (but not a barrier)
      if prob migration-prob [
        while [[barrier?] of patch xm ym] [
          set xm random (max-pxcor + 1)
          set ym random (max-pycor + 1)
        ]
        setxy xm ym
        shift
        set num-migrate num-migrate + 1
      ]
    ]
  ]
  set num-migrate-disp num-migrate ;; update monitor for number moved
  set num-entity-species-disp num-entity-species ;; update monitor for number species
  
  ;; calculate numbers at different trophic levels
  set l0 safeDiv count entities with [level = 0] count entities
  set l1 safeDiv count entities with [level = 1] count entities
  set l2+ safeDiv count entities with [level > 1] count entities
  
  ;; time and pop stats
  set time-per-tick timer
  set pop-display count turtles
  
  ;; do relative species abundance plot and species distribution histograms
  do-sa-plot
  do-sp-dist
  
  if max-time > 0 and ticks  >= (max-time - 1) [
    do-hist  ;; if time do log-log num species vs. area plot
   stop
  ]

  tick ;; increment tick
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  birth and new entity procedures  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to hatch-1-entity
  hatch 1 [
    set energy init-energy
    set gene mutate gene mut-prob-list
    init-entity
    adjust-display
  ]
end

to create-new-entity
  let x random (max-pxcor + 1) 
  let y random (max-pycor + 1)
  create-entities 1 [
    set energy init-energy + random-normal 0 (init-energy / 4)
    set gene n-values gene-size [rand-bin]
    init-entity
    while [[barrier?] of patch x y] [
      set x random (max-pxcor + 1) 
      set y random (max-pycor + 1)
    ]
    setxy x y
    adjust-display
  ]
end

to init-entity
  set age 0
  set level 0
  ifelse table:has-key? species-col-table gene
    [set-col-id]
    [init-new]
  if not table:has-key? entity-num-table species-id [
    table:put entity-num-table species-id 0
    set num-entity-species num-entity-species + 1
  ]
  table:put entity-num-table species-id 1 + table:get entity-num-table species-id
end

to adjust-display
  ifelse level < 1 [
    set size plant-size
    set shape "star"
  ] [
    set shape "circle"
    set size plant-size + level * pred-size-incr
  ]
  shift
end

to set-col-id
  set color table:get species-col-table gene
  set species-id table:get species-id-table gene
end

to init-new
  set species-id-cumm species-id-cumm + 1
  set species-id species-id-cumm
  set color rand-col
  table:put species-col-table gene color
  table:put species-id-table gene species-id
  table:put species-gene-table species-id gene
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  death procedures  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to death
  set energy 0
  if is-entity? self
    [death-entity]
  die
end

to death-entity
  let num-of-this (table:get entity-num-table species-id) - 1
  table:put entity-num-table species-id num-of-this
  if num-of-this < 1 [
    set num-entity-species num-entity-species - 1
    table:remove entity-num-table species-id 
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  dominance procedures  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; returns the relative domminance value of one gene over another, getting the value from a
;; table if calculated before
to-report dv [g1 g2]
  let op 0
  let ky list g1 g2
    ifelse table:has-key? dv-vals ky
      [set op table:get dv-vals ky]
      [set op calc-dv g1 g2
       table:put dv-vals ky op]
  report op 
end

to clear-dv-cache
  table:clear dv-vals
end

;; calculates the relative domminance value given two species IDs
to-report calc-dv [i1 i2]
;;  if affected-char > 0 [
  let op 0
  let i 0
  let g1 table:get species-gene-table i1
  let g2 table:get species-gene-table i2
  foreach (seq1 0 (gene-size - 1)) [
    set i ?
    if (item i g1) != 0 [
      foreach seq1 1 (gene-size - 1) [
        set op op + (item ? g2) * (matrix:get dom-matrix i ?)
      ]
    ]
  ]
  report op
end

;; does one gene domminate another enough to be eaten
to-report dom? [g1 g2]
  if not allow-cannibals? and g1 = g2 [report false]
  report dv g1 g2 > dom-floor
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  move procedures  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to move-near
  let ns neighbors
  if not any? ns [stop]
  let next-patch one-of ns
  while [[barrier?] of next-patch]
    [set next-patch one-of ns]
  setxy [pxcor] of next-patch [pycor] of next-patch
  shift
end

to-report rand-plus-minus
  report (2 * random 2) - 1
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  colour procedures  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report shade [cl]
  report (list chc first cl chc second cl chc last cl)
end

to-report rand-col
  report (list rand-rbg-val rand-rbg-val rand-rbg-val)
end

to-report rand-rbg-val
  report col-thresh + random-float (255 - col-thresh)
end
  
to-report chc [v]
  report min list 255 max list col-thresh ch-val v
end

to-report ch-val [v]
  if v >= 255 [report v - col-incr - random col-incr]
  if v <= col-thresh [report v + col-incr + random col-incr]
  ifelse 0 = random 2
    [report v + col-incr + random col-incr]
    [report v - col-incr - random col-incr]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  mutation procedures  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; simulates a bit point mutation with a set probability but done more efficiently
to-report mutate [g prob-list]
  repeat (pos-in random-float 1 prob-list) [
    set g flip-one g
  ]
  report g
end

to-report flip-one [g]
  let ps random gene-size
  report replace-item ps g (1 - (item ps g))
end

to-report maybe-flip [bt pr]
  ifelse prob pr 
    [set num-muts num-muts + 1
     report 1 - bt]
    [report bt]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  diversity stats  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; the basic diversity measure is the average hamming distant between all pairs of individuals
to calc-pi-stats
  set pi-t 0
  set pi-t safeDiv pi-t sample-size
  set pi-d 0
  set F-st 0
  set pi-env 0
  set F-env 0
  let ot nobody
  let my-gene []
  let ps nobody
  let p nobody
  let p1 nobody
  let p2 nobody
  if any? entities [
    repeat sample-size [
      ask one-of entities [
        set my-gene gene
        if any? other entities
          [ask one-of other entities  [set pi-t pi-t + hamming-dist my-gene gene]]
      ]
    ]
    repeat sample-size [
      ask one-of entities [
        set my-gene gene
        if any? other entities-here 
           [ask one-of other entities-here [set pi-d pi-d + hamming-dist my-gene gene]]
      ]
    ]
    set ps map [entities-on ?] patch-set-list
    repeat sample-size [
       set p random-member ps
       if any? p [
         set p1 one-of p
         ask p1 [set p2  one-of other p]
         if p2 != nobody [
           set pi-env pi-env + hamming-dist [gene] of p1 [gene] of p2
         ]
       ]
    ]
    set pi-d safeDiv pi-d sample-size  
    set pi-t safeDiv pi-t sample-size
    set pi-env safeDiv pi-env sample-size
    set F-st safeDiv (pi-t - pi-d) pi-t
    set F-env safeDiv (pi-t - pi-env) pi-t
    set F-denv safeDiv (pi-env - pi-d) pi-env
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;  plots and histograms  ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to do-hist
  let sz 0
  let xc 0 let yc 0 let xm 0 let ym 0
  let pset no-patches let aset no-turtles let xlist [] let ylist []
  let stat-table table:make
  let ns 0
  while [sz < 2 * max-pxcor / 3] [
    set sz sz + 1
    table:put stat-table sz []
    repeat hist-sample-size [
      set xc random (max-pxcor / 2)
      set yc random (max-pycor / 2)
      set xm (xc + sz - 1) mod max-pxcor
      set ym (yc + sz - 1) mod max-pycor
      set xlist map [? mod max-pxcor] n-values sz [xc + ?]
      set ylist map [? mod max-pycor] n-values sz [yc + ?]
      set pset patches with [member? pxcor xlist and member? pycor ylist]
      set aset entities-on pset
      set ns length remove-duplicates [gene] of aset
      table:put stat-table sz fput ns table:get stat-table sz
    ]
  ]
  set-current-plot  "Log-Log Num species vs area"
  clear-plot
  set sz 0
  let stat-list [] let av 0 let sd 0
  while [sz < max-pxcor / 2] [
    set sz sz + 1
    set stat-list table:get stat-table sz
    set av mean stat-list
    set sd standard-deviation stat-list
    set-current-plot  "Log-Log Num species vs area"
    draw-tick log-scale (sz ^ 2) log-scale av 0.1
    draw-spread log-scale (sz ^ 2) log-scale av 0.1
  ]
end

to do-sp-dist
  ;;; species distribution
  let stat-list []
  let keys table:keys entity-num-table
  while [not empty? keys] [
    set stat-list fput table:get entity-num-table first keys stat-list
    set keys but-first keys
  ]

  set-current-plot  "Species Distribution"
  internal-sp-dist stat-list
end

to internal-sp-dist [lis]
  clear-plot
  set lis sort lis
  let twop 1
  let nm 0
  let vl 0
  while [not empty? lis] [
    set nm 0
    set vl first lis
    while [not empty? lis and vl <= twop] [
      set nm nm + 1
      set lis but-first lis
      if not empty? lis [set vl first lis]
    ]
    plot nm
    set twop 2 * twop
  ]
end

to do-sp-sp-dist [lis]
  ;;; species distribution
  set-current-plot "Sample Patch Sp. Dist."
  internal-sp-dist lis
end

to do-sa-plot
  let tsp count entities
  let stat-list reverse sort map [? / tsp] filter [? > 0] map [second ?] table:to-list entity-num-table
  set-current-plot "Relative Species Abundance"
  internal-sa-plot stat-list
end

to internal-sa-plot [lis]
  clear-plot
  if empty? lis [stop]

  set-plot-x-range 0 1 + length lis
  set-plot-y-range -5 0

  let rnk 0
  plot-pen-down
  while [not empty? lis] [
    plotxy rnk log first lis 10
    set lis bf lis
    set rnk rnk + 1
  ]
end

to do-sp-sa-plot [lis]
  set-current-plot "Sample Patch Rel. Sp. Abun."
  clear-plot
  internal-sa-plot lis
end

to do-sample-hists
  let sp-list init-sample-hists
  let tsp count entities
  do-sp-sp-dist sort sp-list
  do-sp-sa-plot reverse sort map [? / tsp] sp-list
end

to-report init-sample-hists
  set sample-patch-entities entities-on sample-patches
  let stat-list [] let id 0
  let keys table:keys entity-num-table
  foreach keys [
    set id table:get species-id-table ?
    set stat-list fput count sample-patch-entities with [species-id = id] stat-list
  ]
  report filter [? > 0] stat-list
end

to-report log-scale [nm]
  report log (1 + nm) 10
end

to draw-mark [xcent ycent sze]
  plot-pen-up
  plotxy xcent ycent + sze
  plot-pen-down
  plotxy xcent + sze ycent 
  plotxy xcent ycent - sze
  plotxy xcent - sze ycent 
  plotxy xcent ycent + sze
end

to draw-tick [xcent ycent sze]
  plot-pen-up
  plotxy xcent + sze ycent 
  plot-pen-down
  plotxy xcent - sze ycent 
end

to draw-spread [xcent ycent sze]
  plot-pen-up
  plotxy xcent ycent + sze
  plot-pen-down
  plotxy xcent ycent - sze
end

to-report ecology-state
  if count entities < 10 [report "non-viable"]
  if num-entity-species < 2 [report "one-species"]
  if l1 = 0 [report "hebivore"]
  report "mixed"
end

to-report entities-from [ps]
  report entities with [member? patch-here ps]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;  saving and loading world states & matricies ;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to a-a-SAVE-LOAD end

to save-world
  set dom-matrix-list matrix:to-row-list dom-matrix
  set species-col-table-list table:to-list species-col-table
  set entity-num-table-list table:to-list entity-num-table
  set species-id-table-list table:to-list species-id-table
  set species-gene-table-list table:to-list species-gene-table
  export-world (word title "-state.csv")
end

to load-world
  import-world (word title "-state.csv")
  set dom-matrix matrix:from-row-list dom-matrix-list
  set species-col-table table:from-list species-col-table-list
  set entity-num-table table:from-list entity-num-table-list
  set species-id-table table:from-list species-id-table-list
  set species-gene-table table:from-list species-gene-table-list
  set dv-vals-list []
  table:clear dv-vals
  clear-save-lists
end

to clear-save-lists
  set dom-matrix-list []
  set species-col-table-list [] 
  set entity-num-table-list []
  set species-id-table-list []
  set species-gene-table-list []
  set dv-vals-list []
end

to save-dom-mat
  file-open (word "matrix - " title ".dat")
  file-write matrix:to-row-list dom-matrix
  file-close
end

to load-dom-mat
  file-open (word "matrix - " title ".dat")
  set dom-matrix matrix:from-row-list file-read
  file-close
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to a-a-ANALYSIS end

;; for use in multiple runs using behaviour space 
to start-analysis
  clear-dv-cache
  random-seed new-seed
end

;; for use in multiple runs using behaviour space
to end-analysis
  calc-niche-stats
end

;; calculates stats for up to 16 kinds of patch for use in simulation output
to calc-niche-stats
  let p 0 let ps nobody let as nobody let char-num 0
  let list-patch-nums map [num-from-binvec ? num-env-chars] list-patch-chars

  if num-env-chars < 1 [stop]
    set char-num 1
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s1 calc-ns as
  set pi1 calc-pi as
  ]
    set char-num 2
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s2 calc-ns as
  set pi2 calc-pi as
  ]
  if num-env-chars < 2 [stop]
    set char-num 3
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s3 calc-ns as
  set pi3 calc-pi as
  ]
    set char-num 4
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s4 calc-ns as
  set pi4 calc-pi as
  ]
    if num-env-chars < 3 [stop]
    set char-num 5
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s5 calc-ns as
  set pi5 calc-pi as
  ]
    set char-num 6
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s6 calc-ns as
  set pi6 calc-pi as
  ]
    set char-num 7
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s7 calc-ns as
  set pi7 calc-pi as
  ]
    set char-num 8
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s8 calc-ns as
  set pi8 calc-pi as
  ]
  if num-env-chars < 4 [stop]
    set char-num 9
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s9 calc-ns as
  set pi9 calc-pi as
  ]
    set char-num 10
  set p position (char-num - 1) list-patch-nums 
  if p != false [
    set ps item p patch-set-list
    set as entities-from ps
    set s10 calc-ns as
    set pi10 calc-pi as
  ]
    set char-num 11
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s11 calc-ns as
  set pi11 calc-pi as
  ]
    set char-num 12
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s12 calc-ns as
  set pi12 calc-pi as
  ]
    set char-num 13
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s13 calc-ns as
  set pi13 calc-pi as
  ]
    set char-num 14
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s14 calc-ns as
  set pi14 calc-pi as
  ]
      set char-num 15
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s15 calc-ns as
  set pi15 calc-pi as
  ]
    set char-num 16
  set p position (char-num - 1) list-patch-nums 
  if p != false [
  set ps item p patch-set-list
  set as entities-from ps
  set s16 calc-ns as
  set pi16 calc-pi as
  ]
end

to-report calc-pi [ts]
  if count ts <= 1 [report 0]
  let op 0 let t1 nobody let t2 nobody
  repeat sample-size [
    set t1 one-of ts
    ask t1 [set t2 one-of other ts]
    set op op + hamming-dist [gene] of t1 [gene] of t2
  ]
  report op / sample-size
end

to-report calc-ns [ts]
  report length remove-duplicates [gene] of ts
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;   A whole lot of useful utilities  ;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to a-a-GEN-UTILS end

;; makes a number from the binary implicit in a gene or patch characteristic
to-report num-from-binvec [binvec numplaces]
  let op 0
  foreach seq1 0 (numplaces - 1) [
    set op op + (2 ^ ?) * item ? binvec
  ]
  report op
end

;; second of a list
to-report second [l]
  report first but-first l
end

;; safe version of item - no errors if out of range, but gives min or max position item
to-report safe-item [pos lis]
  if pos > (length lis - 1) [report 0]
  report item pos lis
end

;; useful for adding into code
to pause
  if not user-yes-or-no? (word "Continue?") [error "User halted simulation!!"]
end

;; vesrion for functions
to-report showpause [inp]
  if not user-yes-or-no? (word "Value is: " inp " -- Continue?") [error "User halted simulation!!"]
  report inp
end

;; short command for inspecting a particular patch
to ipat [p1 p2]
  inspect patch p1 p2
end

;; returns random member of the list
to-report random-member [ls]
  report item (random length ls) ls
end

;; probability test, makes code easier to read
to-report prob [p]
  report random-float 1 < p
end

;; safe version of sublist, does not give errors if out of range but sensible outputs (such as an empty list)
to-report safeSubList [lis srt en]
  let len length lis
  if en < 1 or srt > len [report []]
  report subList lis max list 0 srt min list en len
end

;; safe version of n-of in case of empty list
to-report safe-n-of [nm lis]
  if any? lis and count lis >= nm [report n-of nm lis]
  report lis
end

;; safe version of one-of in case of empty list
to-report safe-one-of [lis]
  report safe-n-of 1 lis
end

;; strips leading and trailing spaces from string 
to-report strip-spaces [str]
  report strip-leading-spaces strip-trailing-spaces str
end  

to-report strip-leading-spaces [str]
  if empty? str [report str]
  if first str != " " [report str]
  report strip-leading-spaces but-first str
end

to-report strip-trailing-spaces [str]
  if empty? str [report str]
  if last str != " " [report str]
  report strip-trailing-spaces but-last str
end

;; third in list
to-report third [lis]
  report item 2 lis
end

;; useful to add in code to force an error
to XXX
  error "XXX reached"
end

;; useful to insert into code to see value of a passed value
to-report showPass [arg]
  show arg
  report arg
end

;; returns all patches to a certain distance - SLOW
to-report patchesToDist [dist]
  if dist = 0 [report self]
  let patchList []
  foreach seq1 (-1 * dist) dist [
    let xc ?
      foreach seq1 (-1 * dist) dist [
        set patchList fput patch-at xc ? patchList
      ]
  ]
  report patch-set patchList
end

to-report individualsToDist [dist]
  report turtles-on patchesToDist dist
end

;; "distance" between points
to-report distBetween [x1 y1 x2 y2]
  report (max list abs (x1 - x2) abs (y1 - y2))
;;  report sqrt (((x1 - x2) ^ 2) + ((y1 - y2) ^ 2))
end

;; returns a sequence increasing by 1 - useful in foreach loops
to-report seq1 [from upto]
  report n-values (1 + upto - from) [from + ?]
end

;; safe version of division without error messages (divide by 0 gives 0!)
to-report safeDiv [numer denom]
  if denom = 0 and numer = 0 [report 1]
  if denom = 0 [report 0]
  report numer / denom
end  

;; binonomial coefficient
to-report bin-coef [n k]
  report factorial n / (factorial k * factorial (n - k))
end

;; factorial
to-report factorial [n]
  if n = 0 [report 1]
  report  reduce * n-values n [1 + ?]
end

;; position of a number in a sorted list
to-report pos-in [vl lis]
  let ps 0
  let l length lis
  repeat l [
    if vl > item ps lis [report ps]
    set ps ps + 1
  ]
  report l
end
@#$#@#$#@
GRAPHICS-WINDOW
187
10
625
469
-1
-1
21.4
1
10
1
1
1
0
1
1
1
0
19
0
19
1
1
1
ticks
30.0

BUTTON
7
13
62
46
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
64
13
119
46
NIL
go\n
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
6
60
179
93
gene-size
gene-size
1
100
100
1
1
NIL
HORIZONTAL

BUTTON
120
12
175
45
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1010
624
1128
657
num-env-chars
num-env-chars
0
10
3
1
1
NIL
HORIZONTAL

SLIDER
6
96
178
129
migration-prob
migration-prob
0
0.1
0.01
0.001
1
NIL
HORIZONTAL

SLIDER
5
131
177
164
mut-prob
mut-prob
0
0.01
5.0E-5
0.00001
1
NIL
HORIZONTAL

INPUTBOX
319
609
513
669
title
five-slm
1
0
String

INPUTBOX
630
11
694
71
max-time
5000
1
0
Number

SLIDER
1130
624
1252
657
food-rate
food-rate
0
30000
20000
100
1
NIL
HORIZONTAL

SLIDER
5
167
177
200
life-tax
life-tax
0
10
0.05
0.01
1
NIL
HORIZONTAL

SLIDER
5
205
177
238
init-energy
init-energy
0
10
1
.1
1
NIL
HORIZONTAL

SLIDER
4
240
176
273
efficiency
efficiency
0
1
0.9
0.01
1
NIL
HORIZONTAL

SLIDER
4
278
176
311
reproduce-level
reproduce-level
0
10
3
0.1
1
NIL
HORIZONTAL

PLOT
739
320
992
457
Population
Time
Number
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"entities" 1.0 0 -16777216 true "" "if ticks > 0 [plot count entities]"

SLIDER
5
313
177
346
eating-tries
eating-tries
0
10
2
1
1
NIL
HORIZONTAL

MONITOR
631
73
681
118
Eats
num-eat-disp
17
1
11

MONITOR
630
169
680
214
Deaths
num-starve-disp + num-eat-disp
17
1
11

MONITOR
683
73
733
118
Births
num-born-disp
17
1
11

MONITOR
537
519
597
564
Pop
pop-display
17
1
11

PLOT
738
168
991
318
Tropic Level Distribution
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" "set-plot-pen-interval 1"
PENS
"entities" 1.0 1 -16777216 true "" "histogram [level] of entities"

MONITOR
684
475
734
520
Species
num-entity-species-disp
0
1
11

MONITOR
683
122
733
167
Starve
num-starve-disp
17
1
11

MONITOR
633
423
692
468
secs/tick
time-per-tick
2
1
11

SLIDER
4
350
176
383
max-age
max-age
0
1000
0
10
1
NIL
HORIZONTAL

MONITOR
631
122
681
167
Old
num-die-old-disp
17
1
11

SWITCH
15
569
145
602
anti-sym-mat?
anti-sym-mat?
1
1
-1000

SWITCH
16
533
146
566
migrate-near?
migrate-near?
0
1
-1000

MONITOR
631
218
681
263
Migr
num-migrate-disp
17
1
11

BUTTON
536
483
596
516
Calc pis
calc-pi-stats
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
190
475
241
528
NIL
pi-t
2
1
13

MONITOR
244
475
295
528
NIL
pi-d
2
1
13

MONITOR
299
475
350
528
NIL
F-st
2
1
13

MONITOR
579
568
629
613
L0
l0
3
1
11

MONITOR
632
569
684
614
L1
l1
3
1
11

MONITOR
686
569
744
614
L2+
l2+
4
1
11

SLIDER
2
493
185
526
init-new-species-prob
init-new-species-prob
0
0.1
0.01
0.001
1
NIL
HORIZONTAL

PLOT
746
460
994
620
Number of Species
Time
Number
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"entities" 1.0 0 -16777216 true "" "if ticks > 0 [plot num-entity-species]"

SWITCH
647
623
765
656
neutral-env?
neutral-env?
1
1
-1000

SWITCH
150
570
324
603
allow-cannibals?
allow-cannibals?
1
1
-1000

BUTTON
333
536
411
569
Save World
save-world
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
333
572
412
605
Load World
load-world
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
353
475
410
528
pi-env
pi-env
2
1
13

MONITOR
414
477
472
530
F-env
F-env
2
1
13

MONITOR
475
478
533
531
NIL
F-denv
2
1
13

PLOT
740
12
991
166
Log Population Types
Time
Log10 Nm
0.0
1.0
0.0
1.0
true
true
"" ""
PENS
"l0" 1.0 0 -16777216 true "" "if ticks > 1 [plot log (1 + (count entities with [level = 0])) 10]"
"l1" 1.0 0 -15390905 true "" "if ticks > 1 [plot log (1 + (count entities with [level = 1])) 10]"
"l2" 1.0 0 -14985354 true "" "if ticks > 1 [plot log (1 + (count entities with [level = 2])) 10]"
"l3" 1.0 0 -15302303 true "" "if ticks > 1 [plot log (1 + (count entities with [level = 3])) 10]"
"l4+" 1.0 0 -13840069 true "" "if ticks > 1 [plot log (1 + (count entities with [level >= 4])) 10]"

SLIDER
6
421
178
454
rand-death-prob
rand-death-prob
0
0.05
0.05
0.001
1
NIL
HORIZONTAL

MONITOR
682
169
734
214
Rand D.
num-die-rand
0
1
11

SLIDER
5
385
177
418
max-store
max-store
0
100
30
1
1
NIL
HORIZONTAL

MONITOR
633
375
716
420
State
ecology-state
17
1
11

INPUTBOX
1024
13
1110
73
hist-sample-size
100
1
0
Number

BUTTON
1113
39
1190
72
NIL
do-hist
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
995
76
1250
243
Log-Log Num species vs area
NIL
NIL
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"entities" 1.0 0 -16777216 true "" ""

SLIDER
767
624
889
657
patches-across
patches-across
0
100
20
1
1
NIL
HORIZONTAL

MONITOR
631
267
683
312
Muts
num-muts-display
0
1
11

PLOT
995
247
1252
402
Relative Species Abundance
Ranked Species
Log Num
0.0
1.0
-5.0
0.0
false
false
"" ""
PENS
"entities" 1.0 0 -16777216 true "" ""

MONITOR
683
267
734
312
Pop/Patch
pop-display / count patches
2
1
11

MONITOR
1179
563
1248
608
Prop Neigh
prop-neighbours-same
2
1
11

INPUTBOX
998
562
1088
622
target-prop-n
0.5
1
0
Number

INPUTBOX
1092
562
1176
622
max-secs
500
1
0
Number

BUTTON
423
534
507
568
Save Matrix
save-dom-mat
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
423
571
508
605
Load Matrix
load-dom-mat
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
631
315
689
360
Fd/Pch
food-rate / count patches
2
1
11

PLOT
996
406
1252
559
Species Distribution
log 2 abundance
num species
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"entities" 1.0 1 -16777216 true "" ""

SWITCH
150
534
326
567
allow-plant-predators?
allow-plant-predators?
1
1
-1000

INPUTBOX
603
474
680
534
sample-size
10000
1
0
Number

SWITCH
3
460
184
493
stop-new-when-est?
stop-new-when-est?
0
1
-1000

SLIDER
890
624
1009
657
prop-barriers
prop-barriers
0
1
0
0.01
1
NIL
HORIZONTAL

@#$#@#$#@
## SUMMARY

This is a model of different ecoologies developing with evolution.  This is an experimental model that combines elements of a meta-population model with a "McKane" style of simulated evolution (but with individuals rather than populations represented).

Each patch has a set of characteristics composed of a binary vector and a level of resources (energy) that is replenished each simulation tick.  

Each individual of a species has the same gene composed of a vector of fixed length. It also has an energy level and an age. Each iteration a life-tax is subtracted from its energy.  If its energy falls below 0 it dies.  If its energy level exceeds a set level it reproduces into the same patch (with a possible mutation) - the energy of the offspring is subtracted from the parent. If its age exceeds the maximum age it also dies (unless maximum age is set to 0).  There is a small probability of migrating to another patch (there are two settings for this - either to another random patch or only neighboring patches).

Energy is gained in one of two ways:

1. by extraction from the environment by comparing its gene against the vector of characteristics for the patch it is on.  In this case the scores of individuals that are achieve value > 0 determine the distribution of the fixed pot of energy for the patch.

2. by eating other individuals.  Each individual tries to eat a set number of random others on their patch.  The success of this is determined by comparing its gene against the gene of the other.  If the score is greater than a threshold (currently 0) then it eats the other, adsorbing a percentage of the other's energy and the other dying.

Method of "comparison" in (1) and (2) above:

During initialisate a random square matrix with dimension of the same length as a gene is generated (this can be optionally forced to be anti-symmetric).  This matrix determines the score of one gene against another gene or patch characteristic vextor.  All the entries indicated by a "1" in both are summed, the first indicating the selected columns, the second the rows.

New species arise due to a mutation occuring during propagation or the introduction of a new random species from outside.


## OUTPUTS

The world is divided into patches the background colouring indicates its characteristics.  Individuals are small stars (if never eaten another individual) or circles (getting bigger for each other they eat) if they have.  Colouring indicates species.  Position within patches is not significant and randomised.

Tropic Level Distribution is a histogram of the trophic levels.  This is of individuals not species, so if an individual has eaten another that has eaten a 'herbivore' then it has a trophic level of at least 2.

A graph of the number of entities at each trophic level, shown on a logarithmic scale.

Graphs of the population size and number of different genomes (roughly species) in existance.

A line histogram of relative species abundance, with species sorted from most abundant (left) to least (right), on a logarithmic phase.

A histogram of different abundances of species, with the log of abundance determining the bars and how many species are at that abundance on the vertical.

A scatter gram (only calculated on request) of the log of the number of species found against the log of the area species are sampled from.  This is a sample, whose size is given by hist-sample-size, and calculated when the button is pressed.

An number of diversity statistics are estimated

pi-t and pi-d is (an estimate of) the average hamming distance between pairs of indiviuduals in the whole simulation and within patches respectively.

F-st is (pi-t - pi-d) / pi-t and is a measure of the amount of variety between patches.

F-st, pi-t and pi-d are only calculated at the end of simulations or when the button is pressed since it takes a while to calculate them.

L0, L1, L2+ are the number of individuals at trophic levels 0, 1 and above 1.

## INITIALISATION

Patches are initialised with a random set of characteristics depending on num-env-chars.

At the start a population of efficiency * food-rate / life-tax individuals is created with the an energy distibution of init-energy + random-normal 0 (init-energy / 4) and a genetic distribution depending on the initial-species-variety setting (see above).

There are two sensible sets of settings for this simulation:

1. With initial-species-variety=1, new-species-prob=0 -- so the initial variety ensures that some species are viable, resulting in a slow initial decline in number of species.

2. With initial-species-variety=0, new-species-prob>0 -- in this case species are introduced (McKane fashion) one by one until a viable one is discovered.  In this case the stop-new-species-once-established? might be used to stop the introduction of random species after a viable population is established.

## PARAMETERS AND SETTINGS

gene-size - the number of bits in an individual's gene 

num-env-chars - the number of (effective) bits in the characteristics of a patch (functions similar to an individual's gene)

migration-prob - the probability that any individual will move to another patch each time click

mut-prob - the probability that a newly born individual will have its gene mutated

food-rate - how much energy is put into the patches each time click (evenly divided among patches)

life-tax - how much energy subtracted from each individual each time click (dies if energy is 0 or below)

init-energy - the energy of a new born (this is subtracted from the parent at birth)

efficiency - what proportion of energy of something eaten goes to predator (or to herbivore from patch)

reproduce-level - if an individual's energy gets to this point it gives birth once (new born's energy being then ssubtracted from it)

eating-tries - each tick each individual tries to eat this number of others on the same patch, but this only happens if they dominate them via the interaction matrix

max-age - if > 0 individuals die when they reach this age in simulation ticks (otherwise no age ceiling)

max-store - if > 0 this is the upper bound on what energy individuals can accumulate (rest is lost to system)

random-death-prob - the probablity that an entity randomly dies each tick

stop-new-species-once-established? - if set stops new individuals with new genomes being introduced into the simulation once a viable population is established

init-new-species-prob - probability of a new individual with a random geneome being introduced each time click 

anti-sym-mat? - forces the interaction matrix generated at start to be anti-symmetric

migrate-near? - if true then individuals migrate (if they do) to a neighbouring patch if false to a random other patch

allow-cannibals? - if true individuals of the same species can eat each other, if not can only eat those of another species

allow-plant-predators? - if false predators are not allowed to extract energy from its environment - that is one is either a predator or a plant

neutral-env? - if true then all individuals on a patch get the same amount of energy from the patch regardless of their geneome (otherwise they have to dominate the patch via the interaction matrix)

patches-across - the number of patches up and accross that the world is composed of

prop-barriers - the proportion of patches that are barriers (no entity can move there)

num-env-chars - how many bits of characteristic that patches have, e.g. 3 bits means that there are potentially 8 kinds of patch

max-time - if > 0 the time at which the simulation is halted

target-prop-n - the average number of patches adjoining each patch with same characteristics as itself - this is the target, swaps patches around until it is reached.  The monitor "Prop Neigh" shows proportion actually reached.

max-secs - since the above process could go on for ever, a maximum time for this can be set (0 = no maximum)

## SAVING AND LOADING WORLD STATES

title - the title for saving or loading

Save World - allows the whole state of the model to be saved
Load World - allows a previously saved state to be restored so to allow experiments from the same starting point

Save Matrix - allows the dominance matrix (which determines which genes dominate others) to be saved
Load Matris - allows previously saved dominance matricies to be restored

## SECOND STAGE ANALYSIS

At any point the state of the world can be saved to disk or retrieved (using the Save and Load buttons).  When this happens the filename uses that in the "title" input box. 

affected-char - if > 0 this prevents the numbered characteristic being taken into acount during dominance calculations using the interaction matrix.  In other words this characteristic is supressed in terms of its efficacy.

The the Start-A, Do-A and End-A buttons initialise, do and calculate final stats from this point (up to max-time) with the affected-char intervention in place

## OUTPUTS AND MONITORS

In current tick:

Eats - how many are eaten 
Deaths - total systematic deaths (eaten, starve, got too old)
Births - number of new individuals born due to parent reaching required energy 
Pop - number of live individuals
Species - how many distinct genomes there are in living individuals
Starve - how many died of lack of energy
Old - how many died due to reaching max-age
Migr - how many migrated to another patch
Rand Die - how many died randomly (due to rand-death-prob)
secs/tick - how long current simulation tick took to compute (in seconds)
L0 - proportion of individuals that have not eated anyone ever (herbivores)
L1 - proportion of individuals that have ever eaten a herbivore
L2 - proportion of individuals that have ever eaten a carnivore

Only calculated when press Calc button or at end of simulation.  All are about diversity measured as the average hamming distance between pairs of distinct individuals (estimated using random sample of 10000)

pi-t - the overall diversity
pi-d - diversity within patches
F-st - (pi-t - pi-d) / pi-t i.e. how much diversity is inter-patch
pi-env - diversity within all patches with same characteristics
F-env - (pi-t - pi-env) / pi-t how much diversity is inter-ptach-type
F-denv (pi-env - pi-d) / pi-env how much within patch diversity is due to variation between patches with same characteristics

## GRAPHS

Energy Distribution -  histogram of the energy levels of individuals
Tropic Level Distribution - a histogram of number of individuals at each tropic level
Population - graph of number of living individuals
Number of Species - graph of number of distinct geneomes in current population
Log Population Types - graph of the number of individuals at different tropic levels (on a logarithmic scale)

## RELATED MODELS

This model relates to the McKane series of models to simulation the evolution of food webs, to meta-population models and to the "Patterns of genetic variation in populations of infectious agents" paper by Isabel Gordo and Paulo RA Campos in BMC Evoilutionary Biology.

## CREDITS AND REFERENCES

The model is described in:

Edmonds, B. (2014) Man on Earth – the challenge of discovering viable ecological survival strategies. Multi-Agent Based Simulation, Paris, May 2014.

The simulation here can be seen as an ancestor of (Norling et al. 2008).  It uses a variety of the interaction matrix described in (Caldarelli et al 1998). It relates to the ecological model described in (Edmonds 2013) but has only one type of basic resource.

This research was partially supported by the Engineering and Physical Sciences Research Council, grant number EP/H02171X/1.  Many thanks to Emma Norling, who first worked on these kinds of models at the CPM, those I have discussed this and previous versions of this model with, including those at the Manchester Complexity Seminar, especially Alan McKane, and those at iEMSs conference in 2012 for discussions on this subject.

Norling, E., Powell, C and Edmonds, B., 2008. Cross-Disciplinary Views on Modelling Complex Systems. In. David, N. & Sichman, J.S., Eds., Multi-Agent-Based Simulation IX, Springer, Lecture Notes in Artificial Intelligence, 5269, 183-194.

Caldarelli, G., Higgs, P.G. and McKane, A., 1998. Modelling Coevolution in Multispecies Communities. Journal of Theoretical Biology, 193, 345-358.

Edmonds, B. (2013) Multi-Patch Cooperative Specialists With Tags Can Resist Strong Cheaters. In Rekdalsbakken, W., Bye, R.T. and Zhang, H. (eds), Proceedings of the 27th European Conference on Modelling and Simulation (ECMS 2013), May 2013, Alesund, Norway. European Council for Modelling and Simulation, 900-906.

Bruce Edmonds
25/4/2014
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -7500403 true true 135 285 195 285 270 90 30 90 105 285
Polygon -7500403 true true 270 90 225 15 180 90
Polygon -7500403 true true 30 90 75 15 120 90
Circle -1 true false 183 138 24
Circle -1 true false 93 138 24

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment EMS paper base" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper gene size" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="10"/>
      <value value="20"/>
      <value value="30"/>
      <value value="40"/>
      <value value="50"/>
      <value value="60"/>
      <value value="70"/>
      <value value="80"/>
      <value value="90"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper mig prob" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0"/>
      <value value="0.0025"/>
      <value value="0.0050"/>
      <value value="0.0075"/>
      <value value="0.01"/>
      <value value="0.0125"/>
      <value value="0.015"/>
      <value value="0.0175"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper max age" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
      <value value="100"/>
      <value value="125"/>
      <value value="150"/>
      <value value="175"/>
      <value value="200"/>
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper mut prob" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0"/>
      <value value="0.0025"/>
      <value value="0.0050"/>
      <value value="0.0075"/>
      <value value="0.01"/>
      <value value="0.0125"/>
      <value value="0.015"/>
      <value value="0.0175"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper food rate" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="50"/>
      <value value="100"/>
      <value value="150"/>
      <value value="200"/>
      <value value="250"/>
      <value value="300"/>
      <value value="350"/>
      <value value="400"/>
      <value value="450"/>
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper efficiency" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper death prob" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0"/>
      <value value="0.0025"/>
      <value value="0.0050"/>
      <value value="0.075"/>
      <value value="0.01"/>
      <value value="0.0125"/>
      <value value="0.015"/>
      <value value="0.0175"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper num env chars" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper max store" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="10"/>
      <value value="20"/>
      <value value="30"/>
      <value value="40"/>
      <value value="50"/>
      <value value="60"/>
      <value value="70"/>
      <value value="80"/>
      <value value="90"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper new species prob" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.0025"/>
      <value value="0.0050"/>
      <value value="0.0075"/>
      <value value="0.01"/>
      <value value="0.0125"/>
      <value value="0.015"/>
      <value value="0.0175"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper eating tries" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper options" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper 1xn" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper 2xn" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper 3xn" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper 4xn" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper 1-5xn" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper 10xn" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pxcor">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-pycor">
      <value value="0"/>
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
      <value value="8"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very long runs" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="10000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="40000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="40000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run 2" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run 3" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run 4" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run nonanti 1" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run nonanti 2" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run nonanti 3" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run optimised" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-stats</final>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="350"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.0065"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment EMS paper very very long run optimised 10x10" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>cumm-num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>s1</metric>
    <metric>s2</metric>
    <metric>s3</metric>
    <metric>s4</metric>
    <metric>s5</metric>
    <metric>s6</metric>
    <metric>s7</metric>
    <metric>s8</metric>
    <metric>s9</metric>
    <metric>s10</metric>
    <metric>s11</metric>
    <metric>s12</metric>
    <metric>s13</metric>
    <metric>s14</metric>
    <metric>s15</metric>
    <metric>s16</metric>
    <metric>pi1</metric>
    <metric>pi2</metric>
    <metric>pi3</metric>
    <metric>pi4</metric>
    <metric>pi5</metric>
    <metric>pi6</metric>
    <metric>pi7</metric>
    <metric>pi8</metric>
    <metric>pi9</metric>
    <metric>pi10</metric>
    <metric>pi11</metric>
    <metric>pi12</metric>
    <metric>pi13</metric>
    <metric>pi14</metric>
    <metric>pi15</metric>
    <metric>pi16</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="affected-char">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="50000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-species-once-established?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-species-variety">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="350"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.0025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;experiment EMS paper base&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="55"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="0"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp more people migration options" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="0"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0"/>
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp 3 people migration options" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="0"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="0"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0"/>
      <value value="0.0050"/>
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp p var - prob share" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0"/>
      <value value="0.0125"/>
      <value value="0.025"/>
      <value value="0.0375"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp p var - base" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.0125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp p var - learning" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0"/>
      <value value="0.0125"/>
      <value value="0.025"/>
      <value value="0.0375"/>
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.0125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp p var - innov" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="0"/>
      <value value="5.0E-5"/>
      <value value="1.0E-4"/>
      <value value="1.5E-4"/>
      <value value="2.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.0125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="AAMAS - exp p var - base" repetitions="20" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>calc-pi-stats</final>
    <metric>count turtles</metric>
    <metric>num-species</metric>
    <metric>pi-t</metric>
    <metric>pi-d</metric>
    <metric>F-st</metric>
    <metric>pi-env</metric>
    <metric>F-env</metric>
    <metric>F-denv</metric>
    <metric>l0</metric>
    <metric>l1</metric>
    <metric>l2+</metric>
    <metric>ecology-state</metric>
    <enumeratedValueSet variable="allow-cannibals?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-p2p-eat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allow-plant-predators?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="anti-sym-mat?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eating-tries">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-extraction">
      <value value="&quot;proportional&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="food-rate">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gene-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hist-sample-size">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-energy">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-new-species-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-num-people">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="innovation-prob">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="learning-prob">
      <value value="0.025"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="life-tax">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-age">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-secs">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-store">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-time">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migrate-near?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="migration-prob">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mut-prob">
      <value value="5.0E-5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="neutral-env?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-env-chars">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="patches-across">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-enter">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-mig-prob">
      <value value="0.0050"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prop-barriers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rand-death-prob">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="reproduce-level">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sample-size">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prob">
      <value value="0.0125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="share-prop">
      <value value="0.125"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="stop-new-when-est?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="target-prop-n">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="title">
      <value value="&quot;test3&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
